<img src="https://github.com/iGW-TU-Dresden/ISOSIMpy/blob/main/logo.png" width="400">

# ISOSIMpy

Lumped parameter groundwater age simulations with a simple user interface - in Python.

ISOSIMpy is an open-source framework for the analysis of groundwater residence time distributions with lumped parameter models. ISOSIMpy is not only usable as a Python package but is also released as standalone application with a graphical user interface (GUI). The GUI closes the gap in accessibility between complex Python-based workflows and practical applications outside Python.
